#
# spec file for package cpufrequtils
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           cpufrequtils
%define         turbostat_version 20101221
BuildRequires:  doxygen lynx
Url:            http://www.kernel.org/pub/linux/utils/kernel/cpufreq/cpufrequtils.html
Version:        008
Release:        6.7.1
Summary:        Tools to Determine and Set CPUfreq Settings
License:        GPLv2+
Group:          System/Base
Source:         %{name}-%{version}.tar.bz2
Source2:        baselibs.conf
Source3:        turbostat-%{turbostat_version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# bug437293
%ifarch ppc64
Obsoletes:      cpufrequtils-64bit
%endif
#

%description
To make access to the Linux kernel cpufreq subsystem easier for users
and cpufreq userspace tools, the cpufrequtils package was created. It
contains a library used by other programs (libcpufreq), command line
tools to determine current CPUfreq settings and to modify them
(cpufreq-info and cpufreq-set), and debug tools.

Authors:
--------
    Dominik Brodowski <linux@brodo.de>

%package bench
License:        GPLv2+
Summary:        CPU frequency micro benchmark
Group:          System/Benchmark

%description bench
cpufrequtils-bench helps to test the condition of a given kernel cpufreq
governor (e.g. ondemand, userspace, conservative) and the cpufreq HW driver
(e.g. powernow-k8, acpi-cpufreq, ...).
For that purpose, it compares the performance governor to a configured
powersave module.

Authors:
--------
    Christian Kornacker <ckornacker@suse.de>

%package devel
License:        GPLv2+
Summary:        Development files for cpufrequtils
Group:          Development/Libraries/C and C++
Requires:       %{name} >= %{version}

%description devel
Files required for cpufreq userspace tools development

%prep
%setup -q -a 3

%build
# This package failed when testing with -Wl,-as-needed being default.
# So we disable it here, if you want to retest, just delete this comment and the line below.
export SUSE_ASNEEDED=0
CONF="PACKAGE_BUGREPORT=http://bugs.opensuse.org mandir=%_mandir libdir=%_libdir CPUFRQ_BENCH=true STRIP=true"
export CFLAGS="$RPM_OPT_FLAGS"
make $CONF
cd turbostat
export CFLAGS="$CFLAGS -D_GNU_SOURCE"
make
cd ..

%install
CONF="PACKAGE_BUGREPORT=http://bugs.opensuse.org mandir=%_mandir libdir=%_libdir CPUFRQ_BENCH=true DESTDIR=$RPM_BUILD_ROOT sbindir=/usr/sbin docdir=%{_docdir}/%{name} confdir=/etc"
make install DESTDIR=$RPM_BUILD_ROOT $CONF
# copy to examples doc dir to avoid complains from the build
# system about an executable in the doc dir.
mkdir -p $RPM_BUILD_ROOT/%{_docdir}/%{name}/examples
mv $RPM_BUILD_ROOT/%{_docdir}/%{name}/cpufreq-bench_script.sh $RPM_BUILD_ROOT/%{_docdir}/%{name}/examples
%find_lang %{name}

mkdir -p $RPM_BUILD_ROOT/%{_sbindir}
mkdir -p $RPM_BUILD_ROOT/%{_mandir}/man8
install -D -m 0755 turbostat/turbostat $RPM_BUILD_ROOT/%{_sbindir}
install -D -m 0644 turbostat/turbostat.8.gz $RPM_BUILD_ROOT/%{_mandir}/man8

%clean
rm -rf $RPM_BUILD_ROOT

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files -f %{name}.lang
%defattr (-,root,root)
%{_libdir}/libcpufreq.*.0
%{_mandir}/man1/cpufreq*
%{_mandir}/man8/turbostat*
%{_sbindir}/turbostat
/usr/bin/cpufreq-info
/usr/bin/cpufreq-set
/usr/bin/cpufreq-aperf

%files bench -f %{name}.lang
%defattr (-,root,root)
%config /etc/cpufreq-bench.conf
/usr/sbin/cpufreq-bench
/usr/bin/cpufreq-bench_plot.sh
# Can't use %%doc because I want to avoid cpufrequtils-bench doc dir
# and use the cpufrequtils doc dir instead
%dir %{_docdir}/%{name}
%dir %{_docdir}/%{name}/examples
%{_docdir}/%{name}/examples/cpufreq-bench_script.sh
%{_docdir}/%{name}/README-BENCH

%files devel
%defattr (-,root,root)
/usr/include/cpufreq.h
%{_libdir}/libcpufreq.so

%changelog
* Tue May  3 2011 petr@scribus.info
- Create a devel package as it's required for building additional
  applications
* Mon Jan 10 2011 trenn@novell.com
- Accidently added /usr/lib/cpufreq.h -> removed it again
* Fri Jan  7 2011 trenn@novell.com
- Add turbostat util to check/monitor for boosted cpufreq state
  usage and C-state HW usage for Intel CPUs with invariant TSC.
  turbostat got extract from pmutils from here:
  kernel/people/lenb/acpi/utils/pmtools
* Tue Sep  7 2010 aj@suse.de
- Do not package devel files since nobody else needs them.
* Tue Jul  6 2010 trenn@novell.com
- Updating to version 008
  - Aperf fix and cpu hotplug robust patches can now be removed as
    they got included in this release
  - This release makes it easier to cross-compile cpufrequtils
* Thu Apr 29 2010 trenn@novell.com
- Make cpufreq-aperf robust against cpu onlining/offlining.
* Wed Apr 28 2010 trenn@novell.com
- Update to version 007. No features, only cosmetics and fixes
* Sun Jan 31 2010 jengelh@medozas.de
- package baselibs.conf
* Mon Dec 28 2009 trenn@suse.de
- Upgrade to version 006
  New features
  - > cpufreq-aperf shows the average frequency a core run for
    a specific time. This also includes "boosted" frequencies
  - > cpufreq-bench is a micobenchmark to test kernel cpufreq
    governors and HW drivers. The cpufreq-bench is packaged
    in a separate cpufrequtils-bench subpackage.
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Mon Jun 15 2009 seife@suse.de
- update to version 005:
  - documentation fixes
  - fix in /proc reading code (unused on kernel 2.6)
* Sun Jun 14 2009 ro@suse.de
- drop sysfsutils from buildrequires
* Sun Apr 19 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue Jul 15 2008 seife@suse.de
- update to version 004
  - support for cpufreq statistics
  - new translations
  - some minor fixes (memory allocation etc.)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Sun Mar 16 2008 crrodriguez@suse.de
- fix file-not-in-lang problems
* Mon Nov  6 2006 schwab@suse.de
- Don't strip binaries.
* Thu Jun 29 2006 seife@suse.de
- update to upstream version 002 (changed numbering scheme):
  - new Makefile-based build system instead of autotools
  - includes a patch which causes cpufrequtils to always set the
    maximum frequency before the minimum frequency on a policy
    change, as the kernel expects.
* Fri May 26 2006 schwab@suse.de
- Don't strip binaries.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Dec 22 2005 seife@suse.de
- update to version 0.4
* Wed Oct  5 2005 dmueller@suse.de
- add norootforbuild
* Tue Jun 14 2005 seife@suse.de
- update to version 0.3
* Tue Jun 14 2005 ro@suse.de
- added sysfsutils to nfb
* Mon Feb 28 2005 seife@suse.de
- update to version 0.2
* Tue Jan 18 2005 seife@suse.de
- update to version 0.2-pre1
* Tue Dec 21 2004 seife@suse.de
- initial submission, version 0.1
